<?php
/**
 * Related post widget class
 *
 */
class Expressivo_Widget_Related_Posts extends WP_Widget {


	function __construct() {
		$widget_ops = array( 'classname' => 'widget_related_posts', 'description' => esc_html__( 'Your site&#8217;s Related Posts For Detail Page.','expressivo' ) );
		parent::__construct( 'Expressivo_Widget_Related_Posts', esc_html__( 'Related Posts','expressivo' ), $widget_ops );

	}

	function widget( $args, $instance ) {

		ob_start();
		extract( $args );

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Related Posts','expressivo' );
		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 8;

		global $post;
		$taxonomies = get_object_taxonomies( (object) array(
			'post_type' => $post->post_type,
			'public' => true,
			'_builtin' => true,
		) );
		 /* to fetch related posts by categories */
			 $terms = wp_get_post_terms( $post->ID, $taxonomies[0], array(
				 'fields' => 'ids',
			 ) );
			 $postQuery = array(
				'post_type'    => $post->post_type,
				'post_status'  => 'publish',
				'tax_query' => array(
							array(
								'taxonomy' => $taxonomies[0],
								'field' => 'ID',
								'terms' => $terms,
								'operator'  => 'IN',
							),
						 ),
				'posts_per_page' => $number,
				'ignore_sticky_posts' => 1,
				'orderby'      => 'RAND',
				'post__not_in' => array( $post->ID ),
			);
		$my_query = new wp_query( $postQuery );
		$postcount = count( $my_query->posts );
		$posttype_obj = get_post_type_object( $post->post_type );
		$type_post = '';
		if ( $postcount > 1 ) {
			$type_post = esc_html__( 'Entries','expressivo' );
		} else {
			$type_post = esc_html__( 'Entry','expressivo' );
		}
		echo wp_kses( $args['before_widget'], wp_kses_allowed_html( 'post' ) );

		if ( $title ) {

			echo wp_kses( $args['before_title'], wp_kses_allowed_html( 'post' ) );
			echo wp_kses( $title, wp_kses_allowed_html( 'post' ) );
			echo wp_kses( $args['after_title'], wp_kses_allowed_html( 'post' ) );

		}
		$post_lable = ($posttype_obj->labels->menu_name) ? $posttype_obj->labels->menu_name : $type_post;
		if ( $my_query->have_posts() ) :
		?>	
			<ul class="list row">
			<?php global $post;
			while ( $my_query->have_posts() ) : $my_query->the_post();
				$title = @$post->post_title;
				$alt = $post->post_title;
				$time = get_post_meta( $post->ID,'time',true );

				/* Loop to display related posts */

				$post_rel_img = expressivo_image_withinfo( $post->ID,'popular-post-thumb' );
				$post_rel_img = $post_rel_img[0]['file'];
		?>
		
	  <li class="main-view clearfix">
	<div class="view-img">
		<a href="<?php echo esc_url( get_permalink( $post->ID ) ); ?>"><img class="thumb-img" src="<?php echo esc_url( $post_rel_img ); ?>"></a>
	</div>
	<div class="view-desc">
		<h6><a href="<?php  echo esc_url( get_permalink( $post->ID ) ); ?>"><?php the_title(); ?></a></h6>
		<span class="byline"> <cite class="fn"><i class="fa fa-clock-o"></i> <?php echo get_the_time( get_option( 'date_format' ) ); ?></cite></span>
	</div>
	  </li>

			
		<?php endwhile; ?>
		</ul>
		<?php echo wp_kses( $args['after_widget'], wp_kses_allowed_html( 'post' ) ); ?>
		<?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();
		else :
			echo '<p>';
			esc_html_e( 'No Related Posts.','expressivo' );
			echo '</p>';
		endif;
		/* Loop End */

		$cache[ $args['widget_id'] ] = ob_get_flush();

	}

	function update( $new_instance, $old_instance ) {
		return $new_instance;
	}

	function form( $instance ) {

		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
			?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title:','expressivo' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo wp_kses( $title, wp_kses_allowed_html( 'post' ) ); ?>" /></p>

		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php esc_html_e( 'Number of posts to show','expressivo' ); ?>: </label>
		<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo intval( $number ); ?>" size="3" /></p>

	<?php
	}
}
?>
